# ---
# definitions

%define pythonbin %(if [ -x /usr/bin/python2 ] ; then echo "python2" ; else echo "python" ; fi)
%ifarch x86_64
%define python_sitepkgsdir %(echo `%{pythonbin} -c "import sys; print (sys.prefix + '/lib64/python' + sys.version[:3] + '/site-packages/')"`)
%else
%define python_sitepkgsdir %(echo `%{pythonbin} -c "import sys; print (sys.prefix + '/lib/python' + sys.version[:3] + '/site-packages/')"`)
%endif
%define python_compile_opt %{pythonbin} -O -c "import compileall; compileall.compile_dir('.')"
%define python_compile %{pythonbin} -c "import compileall; compileall.compile_dir('.')"
%define ruby_sitedir %(ruby -e 'require "rbconfig"; include Config; print CONFIG["sitedir"] + "/" + CONFIG["MAJOR"] + "." + CONFIG["MINOR"]')

# allow relocation
# Prefix: 	%{_prefix}

# ---
# main package

Name: 		ecasound
Version: 	2.4.4
Release:        1%{?dist}
License: 	GPL
Source: 	http://ecasound.seul.org/download/ecasound-%{version}.tar.gz
URL: 		http://www.eca.cx/ecasound
BuildRoot:	%{_tmppath}/%{name}-%{version}-root-%(id -u -n)
Summary: 	ecasound - multitrack audio processing tool
Group: 		Applications/Multimedia

BuildRequires: gcc-c++, ruby, ruby-devel
BuildRequires: python, python-devel
BuildRequires: alsa-lib-devel, audiofile-devel
BuildRequires: jack-audio-connection-kit-devel
BuildRequires: libsamplerate-devel, libsndfile-devel, ncurses-devel

%description
Ecasound is a software package designed for multitrack audio
processing. It can be used for simple tasks like audio playback, 
recording and format conversions, as well as for multitrack effect 
processing, mixing, recording and signal recycling. Ecasound supports 
a wide range of audio inputs, outputs and effect algorithms. 
Effects and audio objects can be combined in various ways, and their
parameters can be controlled by operator objects like oscillators 
and MIDI-CCs. A versatile console mode user-interface is included 
in the package.

# ---
# library package - ecasound-devel

%package 	devel
Summary: 	Ecasound - development files
Group: 		Applications/Multimedia
	
%description devel
The ecasound-devel package contains the header files and static libraries
necessary for building apps like ecawave and ecamegapedal that
directly link against ecasound libraries.

# ---
# library package - libecasoundc

%package -n 	libecasoundc
Summary: 	Ecasound - libecasoundc
Group: 		Applications/Multimedia

requires: ecasound

%description -n libecasoundc
Ecasound - libecasoundc package. Provides 
C implementation of the Ecasound Control Interface
(ECI). Both static library files and and header 
files are included in the package.

# ---
# pyecasound

%package -n 	pyecasound
Summary: 	Python bindings to ecasound control interface.
Group: 		Applications/Multimedia
Requires: 	ecasound

%description -n pyecasound
Python bindings to Ecasound Control Interface (ECI).

# ---
# rubyecasound

%package -n 	rubyecasound
Summary: 	Ruby bindings to ecasound control interface.
Group: 		Applications/Multimedia
Requires: 	ecasound

%description -n rubyecasound
Ruby bindings to Ecasound Control Interface (ECI).

# ---
# build phase

%prep
%setup -q -n ecasound-%{version}

%build
# add redhat/fedora optimizations, do not build with -g
#export AM_CFLAGS=" `echo %{optflags}|sed 's/-O2 -g//g'`" 
#export AM_CXXFLAGS=" `echo %{optflags}|sed 's/-O2 -g//g'`"
%ifarch x86_64
export AM_CXXFLAGS=" `echo %{optflags}|sed 's/-O2 -g/-g -O2 -fPIC/g'`"
export AM_CFLAGS=" `echo %{optflags}|sed 's/-O2 -g/-g -O2 -fPIC/g'`"
%endif

./configure --prefix=%{_prefix} --mandir=%{_mandir} --disable-static --with-largefile $extra_params
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}

%{__make} DESTDIR="%{buildroot}" install-strip
%ifarch x86_64
%{__mkdir} -p %{buildroot}%{python_sitepkgsdir}
%endif
( cd pyecasound
  %python_compile_opt
  %python_compile
  %{__install} *.pyc *.pyo %{buildroot}%{python_sitepkgsdir}
)
%ifarch x86_64
%{__mv}	%{buildroot}NO/lib-dynload/* %{buildroot}%{python_sitepkgsdir}
%{__mv} %{buildroot}/usr/lib/* %{buildroot}/usr/lib64
%endif

# note! this is needed for automake 1.4 and older
%{__strip} --strip-unneeded \
	${RPM_BUILD_ROOT}%{_bindir}/ecasound \
	${RPM_BUILD_ROOT}%{_bindir}/ecaconvert \
	${RPM_BUILD_ROOT}%{_bindir}/ecafixdc \
	${RPM_BUILD_ROOT}%{_bindir}/ecanormalize \
	${RPM_BUILD_ROOT}%{_bindir}/ecaplay \
	${RPM_BUILD_ROOT}%{_bindir}/ecasignalview \
	${RPM_BUILD_ROOT}%{_libdir}/libecasound.a \
	${RPM_BUILD_ROOT}%{_libdir}/libecasoundc.a \
	${RPM_BUILD_ROOT}%{_libdir}/libkvutils.a

# ---
# cleanup after build

%clean
%{__rm} -rf %{buildroot}

# ---
# files sections (main)

%files
%defattr(-, root, root)
%doc NEWS COPYING COPYING.GPL COPYING.LGPL README INSTALL AUTHORS BUGS TODO examples
%doc Documentation/*.html
%doc Documentation/*.txt
%{_mandir}/man1/eca*
%{_mandir}/man5/eca*
%{_bindir}/ecasound
%{_bindir}/ecaconvert
%{_bindir}/ecafixdc
%{_bindir}/ecamonitor
%{_bindir}/ecanormalize
%{_bindir}/ecalength
%{_bindir}/ecaplay
%{_bindir}/ecasignalview
%{_datadir}/ecasound/ecasoundrc
%{_datadir}/ecasound/ecasound.el
%config %{_datadir}/ecasound/ecasoundrc
%config %{_datadir}/ecasound/generic_oscillators
%config %{_datadir}/ecasound/effect_presets

# ---
# files sections (devel)

%files 		devel
%defattr(-, root, root)
%{_bindir}/libecasound-config
%{_includedir}/kvutils
%{_includedir}/libecasound
%{_libdir}/libecasound.la
%{_libdir}/libecasound.a
%{_libdir}/libkvutils.la
%{_libdir}/libkvutils.a

# ---
# files sections (libecasoundc)

%files -n 	libecasoundc
%defattr(-, root, root)
%{_bindir}/libecasoundc-config
%{_includedir}/libecasoundc
%{_libdir}/libecasoundc.la
%{_libdir}/libecasoundc.a

# ---
# files sections (pyecasound)

%files -n 	pyecasound
%defattr(644,root,root,755)
%attr(755,root,root) %{python_sitepkgsdir}/*.so
%{python_sitepkgsdir}/*.pyo
%{python_sitepkgsdir}/*.pyc
%{python_sitepkgsdir}/*.py

# ---
# files sections (rubyecasound)

%files -n 	rubyecasound
%defattr(644,root,root,755)
%{ruby_sitedir}/ecasound.rb

# ---
# changelog

%changelog
* Mon Apr 17 2006 Eddy Nigg <eddy_nigg@startcom.org>
- Rebuild for StartCom Linux 5.0.x
- Upgrade to version 2.4.4

* Mon May 30 2005 Eddy Nigg <eddy_nigg@startcom.org>
- more changes for StartCom Linux 4.0.x

* Fri Apr  8 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.1-1
- updated to 2.4.1, removed support for building with arts
* Tue Mar 22 2005 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.4.0-1
- updated to 2.4.0, added patch to fix arts support (from cvs snapshot)
* Sun Dec 19 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 
- spec file cleanup
* Mon Nov 15 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.5-1
- updated to 2.3.5
- add instruction ordering optimizations to build, ecasound uses
  AM_CFLAGS and AM_CXXFLAGS. Do not compile -g.
* Wed May  5 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.3-1
- updated to 2.3.3
- forced use of python2 under 7.3 (can't use "import as" in 1.5)
* Fri Dec  5 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.2-1
- updated to 2.3.2, added rubyecasound
* Wed Nov 19 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.1-1
- added missing preset.h include file
* Tue Nov 18 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.1-1
- updated to 2.3.1
* Fri Nov  7 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.0-2
- added flags for building with alsa > 0.9.8
* Fri Aug 29 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.3.0-1
- updated to 2.3.0, added release tags
* Wed Aug 20 2003 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- added 'AUTHORS' file
* Wed May 21 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.3-2
- rebuilt with --with-largefile option
- added patch for audiofile support
* Tue May  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.3-1
- updated to 2.2.3
* Mon Apr  7 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.2-1
- under rh9 the "install" macro call in the changelog was triggering
  a "package already defined debuginfo" error
- updated to current cvs so that it can compile with the latest jack
- fixed files lists
* Tue Mar 18 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 2.2.2-1
- updated to 2.2.2
* Sat Feb 15 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- updated to 2.2.1
* Mon Jan 20 2003 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- added Serial tag to differentiate between 2.2 pre and 
  final releases
* Sun Jan 19 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- rebuild 2.2.0 for Planet CCRMA

* Sat Nov 02 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- ported Fernando Lopez-Lezcano's changes to unify this
  spec file with PlanetCCRMA's ecasound package; see
  http://ccrma-www.stanford.edu/planetccrma/software/soundapps.html
- ecasound.el added to package (installed as a data
  file to avoid dependency to emacs/elisp)
- removed unnecessary raw documentation source files
- man files are no longer installed as doc files
- use redhat style mandir location 

* Thu Oct 31 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- minor layout changes
- added TODO to the package
- changed to use rpmrc dir variables

* Thu Oct 24 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- added the COPYING files to the package

* Thu Oct 17 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- added the -devel package
- fixed the build procedure to handle static builds

* Wed Oct 16 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- removed all shared libraries and subpackages containing 
  them
- ecamonitor binary added to main package

* Sat Oct 05 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- changed libecasoundc versioning back to normal libtool style

* Thu Apr 25 2002 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- libraries put to separate subpackages, interface 
  version numbers code to library names
- ecasound-config renamed to libecasound-config
- ecasoundc-config renamed to libecasoundc-config
- plugin install dir changed from prefix/lib/ecasound-plugins
  to prefix/lib/libecasoundX-plugins
- 'contrib' directory removed
- ecasound-plugins subpackage renamed to libecasoundX-plugins

* Mon Oct 01 2001 Kai Vehmanen <kai.vehmanen@wakkanet.fi>
- dropped the hardcoded python module path from configure
  argument list

* Wed Jan 17 2001 Kai Vehmanen <kaiv@wakkanet.fi>
- python subpackage config (thanks to wrobell / PLD Linux!)

* Sat Dec 06 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- contrib and examples directories added to docs
- ecasoundc-config added
- libecasoundc added (C implementation of ECI)
- a new package: pyecasound

* Sat Nov 25 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- ecasignalview added to the package.

* Thu Aug 31 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- Added /etc/ld.so.conf modification script.
- Added DESTDIR to %%install.

* Wed Aug 30 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- 'ecasound-config' script added.

* Sun Aug 20 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- All Qt-related stuff removed.

* Wed Jul 06 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- Added the -plugins package.

* Wed Jun 07 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- ecaconvert added to the package.

* Mon Jun 05 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- Renamed ecatools programs.

* Mon Apr 15 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- Removed dynamic linking to ALSA libraries. You 
  can get ALSA support by recompiling the source-RPM
  package.

* Mon Feb 10 2000 Kai Vehmanen <kaiv@wakkanet.fi>
- Added libqtecasound to ecasound-qt.

* Mon Nov 09 1999 Kai Vehmanen <kaiv@wakkanet.fi>
- A complete reorganization. Ecasound distribution is now 
  divided to three RPMs: ecasound, ecasound-qt and ecasound-devel.

* Mon Nov 08 1999 Kai Vehmanen <kaiv@wakkanet.fi>
- As Redhat stopped the RHCN project, so these rpms 
  are again distributed via Redhat's contrib service
- You can also get these from http://ecasound.seul.org/download

* Sun Aug 15 1999 Kai Vehmanen <kaiv@wakkanet.fi>
- Initial rhcn release.
